summaryrefslogtreecommitdiff
path: root/test/unit/node/kind_black.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'test/unit/node/kind_black.cpp')
-rw-r--r--test/unit/node/kind_black.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/test/unit/node/kind_black.cpp b/test/unit/node/kind_black.cpp
index a33955152..9c497f026 100644
--- a/test/unit/node/kind_black.cpp
+++ b/test/unit/node/kind_black.cpp
@@ -9,9 +9,9 @@
** All rights reserved. See the file COPYING in the top-level source
** directory for licensing information.\endverbatim
**
** \brief Black box testing of CVC4::Kind.
**
** Black box testing of CVC4::Kind.
**/
#include <iostream>
@@ -21,7 +21,7 @@
#include "expr/kind.h"
#include "test.h"
-namespace CVC4 {
+namespace CVC5 {
using namespace kind;
@@ -87,4 +87,4 @@ TEST_F(TestNodeBlackKind, output_concat)
ASSERT_EQ(act.str(), exp.str());
}
} // namespace test
-} // namespace CVC4
+} // namespace CVC5
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback
@@ -9,9 +9,9 @@
** directory for licensing information.\endverbatim
**
- ** \brief Black box testing of CVC4::Kind.
+ ** \brief Black box testing of CVC5::Kind.
**
@@ -9,9 +9,9 @@
**
- ** Black box testing of CVC4::Kind.
+ ** Black box testing of CVC5::Kind.
**/
#include <iostream>